LineText class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

LineText({String? type, String? content, int? size = 0, int? align = ALIGN_LEFT, int? weight = 0, int? width = 0, int? height = 0, int? fontZoom = 1, int? underline = 0, int? linefeed = 0, int? x = 0, int? relativeX = 0, int? y = 0})
LineText.fromJson(Map<String, dynamic> json)
factory

Properties

align → int?
'text' text align
final
content → String?
'text','barcode','qrcode','image' need print content
final
fontZoom → int?
'text' font zoom level, 1 normal, >1 double size
final
hashCode → int
The hash code for this object.
no setterinherited
height → int?
final
linefeed → int?
'text' print linebreak
final
relativeX → int?
'text' relative position from last content
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
'qrcode' qrcode size ,only when type is qrcode
final
type → String?
print type ,inculde'text','barcode','qrcode','image'
final
underline → int?
'text' show underline
final
weight → int?
'text' double
final
width → int?
final
x → int?
'text' absolute position from line begin
final
y → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

ALIGN_CENTER → const int
ALIGN_LEFT → const int
ALIGN_RIGHT → const int
TYPE_BARCODE → const String
TYPE_IMAGE → const String
TYPE_QRCODE → const String
TYPE_TEXT → const String